X-Git-Url: https://git.rapsys.eu/userbundle/blobdiff_plain/71c0edfd65c95bd05705d7c037766f477aac2791..9b89f985a35d8ed9c673ac77aa3ab3c1e211aa76:/Entity/Group.php

diff --git a/Entity/Group.php b/Entity/Group.php
index 1141f91..670e5b7 100644
--- a/Entity/Group.php
+++ b/Entity/Group.php
@@ -1,7 +1,7 @@
 <?php declare(strict_types=1);
 
 /*
  * This file is part of the Rapsys PackBundle package.
  *
  * (c) Raphaël Gertz <symfony@rapsys.eu>
  *
@@ -11,7 +11,9 @@
 
 namespace Rapsys\UserBundle\Entity;
 
+use Doctrine\Common\Collections\Collection;
 use Doctrine\Common\Collections\ArrayCollection;
+use Doctrine\ORM\Event\PreUpdateEventArgs;
 
 use Rapsys\UserBundle\Entity\User;
 
@@ -20,37 +22,36 @@ use Rapsys\UserBundle\Entity\User;
  */
 class Group {
 	/**
-	 * @var integer
+	 * Primary key
 	 */
-	protected $id;
+	protected ?int $id = null;
 
 	/**
-	 * @var string
+	 * Create datetime
 	 */
-	protected $title;
+	protected \DateTime $created;
 
 	/**
-	 * @var \DateTime
+	 * Update datetime
 	 */
-	protected $created;
+	protected \DateTime $updated;
 
 	/**
-	 * @var \DateTime
+	 * Users collection
 	 */
-	protected $updated;
-
-	/**
-	 * @var ArrayCollection
-	 */
-	protected $users;
+	protected Collection $users;
 
 	/**
 	 * Constructor
 	 *
 	 * @param string $title The group name
 	 */
-	public function __construct(string $title) {
-		$this->title = (string) $title;
+	public function __construct(protected string $title) {
+		//Set defaults
+		$this->created = new \DateTime('now');
+		$this->updated = new \DateTime('now');
+
+		//Set collections
 		$this->users = new ArrayCollection();
 	}
 
@@ -59,7 +60,7 @@ class Group {
 	 *
 	 * @return integer
 	 */
-	public function getId(): int {
+	public function getId(): ?int {
 		return $this->id;
 	}
 
@@ -68,9 +69,9 @@ class Group {
 	 *
 	 * @param string $title The group name
 	 *
-	 * @return User
+	 * @return Group
 	 */
-	public function setTitle(string $title) {
+	public function setTitle(string $title): Group {
 		$this->title = $title;
 
 		return $this;
@@ -81,7 +82,7 @@ class Group {
 	 *
 	 * @return string
 	 */
-	public function getTitle(): ?string {
+	public function getTitle(): string {
 		return $this->title;
 	}
 
@@ -90,9 +91,9 @@ class Group {
 	 *
 	 * @param \DateTime $created
 	 *
-	 * @return User
+	 * @return Group
 	 */
-	public function setCreated(\DateTime $created) {
+	public function setCreated(\DateTime $created): Group {
 		$this->created = $created;
 
 		return $this;
@@ -112,9 +113,9 @@ class Group {
 	 *
 	 * @param \DateTime $updated
 	 *
-	 * @return User
+	 * @return Group
 	 */
-	public function setUpdated(\DateTime $updated) {
+	public function setUpdated(\DateTime $updated): Group {
 		$this->updated = $updated;
 
 		return $this;
@@ -160,6 +161,17 @@ class Group {
 		return $this->users;
 	}
 
+	/**
+	 * {@inheritdoc}
+	 */
+	public function preUpdate(PreUpdateEventArgs $eventArgs) {
+		//Check that we have a group instance
+		if (($user = $eventArgs->getObject()) instanceof Group) {
+			//Set updated value
+			$user->setUpdated(new \DateTime('now'));
+		}
+	}
+
 	/**
 	 * Returns a string representation of the group
 	 *
@@ -175,6 +187,7 @@ class Group {
 	 * @return string
 	 */
 	public function getRole(): string {
+		//XXX: $prefix = 'ROLE_' set in Role*Voter classes
 		return 'ROLE_'.strtoupper($this->title);
 	}
 }
@@ -1,7 +1,7 @@
 
 /*
- * This file is part of the Rapsys PackBundle package.
+ * This file is part of the Rapsys UserBundle package.
  *
  * (c) Raphaël Gertz <symfony@rapsys.eu>